@@ -409,6 +409,7 @@ def nano_filterBC(sample_read_dict, guide_file, copy = True, sampleCOL="Samples_
 #################################################################
 
 # nano_fish() - separate mixed libraries?
+
 def process(lines=None):
     ks = ["name", "sequence", "optional", "quality"]
     return {k:v for k, v in zip(ks, lines)}
@@ -418,6 +419,7 @@ def changeFastqHeader(fastq, newrecordname=None, n=4, out="changeFastqHeader.fas
     with open(out, "w") as out:
         with open(fastq, "r") as fh:
             lines = []
+            print(f"Opening {fastq}")
             for line in fh:
                 lines.append(line.rstrip())
                 if len(lines) == n:
@@ -427,18 +429,25 @@ def changeFastqHeader(fastq, newrecordname=None, n=4, out="changeFastqHeader.fas
                         newheader = newrecordname + "|" + record_id
                         record["name"] = newheader
 
-                    print(record["name"], sep="", file=out)
+                    print("@"+record["name"], sep="", file=out)
                     print(record["sequence"], sep="", file=out)
                     print(record["optional"], sep="", file=out)
                     print(record["quality"], sep="", file=out)
                     lines = []
 
-    
-
 
 
 def nano_modiheader(sample_read_dict, filetype="fasta", out="Modified_header", exist_ok=True):
-    
+    """Modify read name to SampleID|BC|readid
+
+    Args:
+        sample_read_dict ([type]): [description]
+        filetype (str, optional): [description]. Defaults to "fasta".
+        out (str, optional): [description]. Defaults to "Modified_header".
+        exist_ok (bool, optional): [description]. Defaults to True.
+    """
+
+
     assert type(sample_read_dict) == defaultdict, "input is a python dictionary with {sample:path, ...}"
 
     os.makedirs(out, exist_ok=exist_ok)
@@ -517,4 +526,4 @@ def nano_krakenReport(sample_read_dict, saveSummary="classfication_summary.txt")
                 print(f"{os.path.basename(sample)}", f"{os.path.basename(f)}", f"{total_n}", f"{n_classified}", f"{n_unclassified}", f"{100*n_classified/total_n:.4f}", f"{100*n_unclassified/total_n:.4f}",sep="\t", file=su)
 
 
-        print(f"Total", f"all_files", f"{total_count}", f"{classified_count}", f"{unclassified_count}", f"{100*classified_count/total_count:.4f}", f"{100*unclassified_count/total_count:.4f}",sep="\t", file=su)
\ No newline at end of file
+        print(f"Total", f"all_files", f"{total_count}", f"{classified_count}", f"{unclassified_count}", f"{100*classified_count/total_count:.4f}", f"{100*unclassified_count/total_count:.4f}",sep="\t", file=su)
